ImageBundleLoader class

An ImageLoader that loads image resources from a Flutter AssetBundle.

Constructors

ImageBundleLoader({required AssetBundle bundle, String pathPrefix = "packages/mapsforge_flutter_rendertheme/assets/"})
Creates a new ImageBundleLoader.
const

Properties

bundle → AssetBundle
final
hashCode → int
The hash code for this object.
no setterinherited
pathPrefix → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchResource(String src) → Future<Uint8List?>
Fetches the image resource from the asset bundle.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited