DummyRenderer class

The dummy renderer renders dummy bitmaps for each given job

Inheritance

Constructors

DummyRenderer({int delayMilliseconds = 0})

Properties

delayMilliseconds → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes of renderer resources and cleans up.
inherited
executeJob(JobRequest job) → Future<JobResult>
Executes a rendering job to generate a tile bitmap.
override
getRenderKey() → String
Returns a unique cache key for this renderer configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveLabels(JobRequest job) → Future<JobResult>
Retrieves labels for separate rendering to support map rotation.
override
supportLabels() → bool
Returns whether this renderer supports separate label rendering.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited