HgtInfo class

A kind of cache for hgt calculation. The projections is always the same while calculating for a tile and the file is mostly the same - except for calculations beyond the boundary of the hgt file.

Constructors

HgtInfo({required PixelProjection projection, required HgtProvider hgtProvider})

Properties

hashCode int
The hash code for this object.
no setterinherited
hgtFile HgtFile?
getter/setter pair
hgtProvider HgtProvider
final
projection → PixelProjection
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

elevationAt(double latitude, double longitude) int?
Only for HillshadingRenderer
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render({required Mappoint leftUpper, required int tileSize, required HgtTileRenderer tileRenderer, required Uint8List pixels}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited