HgtRastering class

///////////////////////////////////////////////////////////////////////////

Constructors

HgtRastering(List<double> xPositions, List<double> yPositions, Int16List elevations)

Properties

elevations → Int16List
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xPositions → List<double>
final
yPositions → List<double>
final

Methods

elevation(int col, int row) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited