ImageHelper class

A helper class for creating placeholder and error tile bitmaps.

Constructors

ImageHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createErrorBitmap(dynamic error) → Future<TilePicture>
Creates a tile bitmap to display an error message.
createMissingBitmap() → Future<TilePicture>
Creates a tile bitmap to indicate that the tile is currently being rendered.
createNoDataBitmap() → Future<TilePicture>
Creates a tile bitmap to indicate that no map data is available for this tile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited