ShapePainterCircle class

Shape painter for rendering circles on the map.

This painter is responsible for drawing circles, typically for POIs, with specified fill and stroke properties.

Properties

fill ↔ UiPaint?
The paint used for the circle fill. Null if the fill is transparent.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
renderinstruction → RenderinstructionCircle
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stroke ↔ UiPaint?
The paint used for the circle stroke. Null if the stroke is transparent.
latefinal

Methods

calculatePath(List<List<Mappoint>> coordinatesAbsolute, Mappoint reference, double dy) → UiPath
Calculates a UiPath from a list of absolute geo-coordinates.
inherited
dispose() → void
ShapePainterLineSymbol and ShapePainterSymbol holds SymbolImage instances which must be disposed after use.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderNode(RenderInfo<Renderinstruction> renderInfo, RenderContext renderContext, NodeProperties nodeProperties) → void
Renders a circle for a node (e.g., a POI).
renderWay(RenderInfo<Renderinstruction> renderInfo, RenderContext renderContext, WayProperties wayProperties) → void
Circles are not rendered for ways.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(RenderinstructionCircle renderinstruction) → Future<ShapePainterCircle>
Creates a new circle shape painter with asynchronous initialization.