ShapePainterPolylineText class

Shape painter for rendering text along a polyline.

This painter is responsible for drawing text that follows the path of a line, such as a street name. It handles text styling, including fill and stroke (for halo effects), and calculates the correct position and rotation for the text along the line.

Properties

hashCode → int
The hash code for this object.
no setterinherited
paintBack ↔ UiPaint?
The paint used for the text stroke (halo). Null if the stroke is transparent.
latefinal
paintFront ↔ UiPaint?
The paint used for the text fill. Null if the fill is transparent.
latefinal
renderinstruction → RenderinstructionPolylineText
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textPaint ↔ UiTextPaint
latefinal

Methods

calculatePath(List<List<Mappoint>> coordinatesAbsolute, Mappoint reference, double dy) → UiPath
Calculates a UiPath from a list of absolute geo-coordinates.
inherited
dispose() → void
ShapePainterLineSymbol and ShapePainterSymbol holds SymbolImage instances which must be disposed after use.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renderNode(RenderInfo<Renderinstruction> renderInfo, RenderContext renderContext, NodeProperties nodeProperties) → void
Renders text for a node.
renderWay(RenderInfo<Renderinstruction> renderInfo, RenderContext renderContext, WayProperties wayProperties) → void
Renders text along a way.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create(RenderinstructionPolylineText renderinstruction) → Future<ShapePainterPolylineText>
Creates a new polyline text shape painter with asynchronous initialization.