TilePicture class

A container for either a ui.Picture (a recorded sequence of drawing commands) or a ui.Image (raw pixel data).

This class is used to represent a rendered map tile. It can be created from either a picture or a bitmap, and it handles the disposal of the underlying graphics resources. It is crucial to call dispose when the tile is no longer needed.

Constructors

TilePicture.fromBitmap(Image? _image)
Creates a TilePicture from a ui.Image.
TilePicture.fromPicture(Picture? _picture)
Creates a TilePicture from a ui.Picture.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → TilePicture
Creates a clone of this TilePicture.
convertPictureToImage() → Image
Converts the underlying ui.Picture to a ui.Image.
dispose() → void
Disposes the underlying ui.Picture and/or ui.Image to release their resources.
getImage() → Image?
Returns the underlying ui.Image, if it exists. Do not forget to dispose() the handle.
getPicture() → Picture?
Returns the underlying ui.Picture, if it exists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited