HgtFile class

Properties

baseLat int
final
baseLon int
final
columns int
final
hashCode int
The hash code for this object.
no setterinherited
latHeight int
final
lonWidth int
width of this file in degree lon
final
rows int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

elevation(int col, int row) int
elevationAt(double latitude, double longitude) int?
Returns the elevation in meters for the given lat/lon.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
raster(PixelProjection projection) HgtRastering?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

readFromFile(File file, {required int baseLat, required int baseLon, required int tileWidth, required int tileHeight, required int rows}) HgtFile

Constants

invalid → const int
ocean → const int