HgtFileProvider class
- Inheritance
-
- Object
- HgtProvider
- HgtFileProvider
Constructors
- HgtFileProvider({required String directoryPath, int maxEntries = 256, int columnsPerDegree = 120, int step = 2})
Properties
- columnsPerDegree → int
-
final
- directoryPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxEntries → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → int
-
final
Methods
-
buildFilename(
{required int baseLat, required int baseLon}) → String -
getForLatLon(
double latitude, double longitude) → HgtFile -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited