HgtTileColorRenderer class
- Implemented types
Constructors
-
HgtTileColorRenderer({int minElevation = 0, int maxElevation = 2000, int metersPerColorStep = 5, List<
Color> colors = const [Color.fromRGBO(0, 191, 191, 1), Color.fromRGBO(0, 255, 0, 1), Color.fromRGBO(255, 255, 0, 1), Color.fromRGBO(255, 127, 0, 1), Color.fromRGBO(191, 127, 63, 1), Color.fromRGBO(120, 120, 120, 1)], Color oceanColor = const Color(0xffB3DDFF)}) - Taken from http://soliton.vm.bytemark.co.uk/pub/cpt-city/grass/tn/elevation.png.index.html
Properties
-
colors
→ List<
Color> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxElevation → int
-
final
- metersPerColorStep → int
-
final
- minElevation → int
-
final
- oceanColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
chooseColor(
int terrainAltitude) → Color -
getRenderKey(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Uint8List pixels, int tileSize, int px, int py, PixelProjection projection, double latitude, double longitude, int elev) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited