HgtTileGreyRenderer class

Implemented types

Constructors

HgtTileGreyRenderer({Color oceanColor = Colors.transparent})

Properties

hashCode int
The hash code for this object.
no setterinherited
oceanColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getRenderKey() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Uint8List pixels, int tileSize, int px, int py, PixelProjection projection, double latitude, double longitude, int elev) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited