IsolateDatastoreRenderer class

Testing if rendering in an isolate works. Unfortunately not since it is currently not allowed to call ui methods from another isolate.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Disposes of renderer resources and cleans up.
override
executeJob(JobRequest jobRequest) Future<JobResult>
Executes a rendering job to generate a tile bitmap.
override
getRenderKey() String
Returns a unique cache key for this renderer configuration.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveLabels(JobRequest jobRequest) Future<JobResult>
Retrieves labels for separate rendering to support map rotation.
override
supportLabels() bool
Returns whether this renderer supports separate label rendering.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

renderer DatastoreRenderer?
The instance of the mapfile in the isolate
getter/setter pair

Static Methods

createRenderer({required Rendertheme rendertheme, required Datastore datastore}) Future<IsolateDatastoreRenderer>
Creates a new IsolateMapfile instance.